summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
index 5ada8db6..5f1f5dcc 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
@@ -89,22 +89,22 @@ public:
void hideIfNeeded();
/**
* Save the config using a KConfig object
*
* The combination of the group_or_prefix variable and the parent
* dockwidget's name will be the group the configuration is saved in
* \param group_or_prefix the prefix to append to the parent dockwidget's name
*/
- virtual void save( KConfig *, const TQString& group_or_prefix );
+ virtual void save( TDEConfig *, const TQString& group_or_prefix );
/**
* Load the config using a KConfig object
*
* The combination of the group_or_prefix variable and the parent
* dockwidget's name will be the group the configuration is loaded from
* \param group_or_prefix the prefix to append to the parent dockwidget's name
*/
- virtual void load( KConfig *, const TQString& group_or_prefix );
+ virtual void load( TDEConfig *, const TQString& group_or_prefix );
/**
* Save the config to a TQDomElement
@@ -89,22 +89,22 @@ public:
void hideIfNeeded();
/**
- * Save the config using a KConfig object
+ * Save the config using a TDEConfig object
*
* The combination of the group_or_prefix variable and the parent
@@ -89,22 +89,22 @@ public:
/**
- * Load the config using a KConfig object
+ * Load the config using a TDEConfig object
*
* The combination of the group_or_prefix variable and the parent